CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
78 lines
1.9 KiB
C++
78 lines
1.9 KiB
C++
// Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
// SPDX-License-Identifier: MIT
|
|
|
|
#pragma once
|
|
|
|
#include "ck_tile/core/config.hpp"
|
|
#include "ck_tile/host/hip_check_error.hpp"
|
|
#include "ck_tile/host/high_res_cpu_clock.hpp"
|
|
#include <hip/hip_runtime.h>
|
|
#include <cstddef>
|
|
|
|
namespace ck_tile {
|
|
|
|
struct gpu_timer
|
|
{
|
|
CK_TILE_HOST gpu_timer()
|
|
{
|
|
HIP_CHECK_ERROR(hipEventCreate(&start_evt));
|
|
HIP_CHECK_ERROR(hipEventCreate(&stop_evt));
|
|
}
|
|
|
|
CK_TILE_HOST ~gpu_timer() noexcept(false)
|
|
{
|
|
HIP_CHECK_ERROR(hipEventDestroy(start_evt));
|
|
HIP_CHECK_ERROR(hipEventDestroy(stop_evt));
|
|
}
|
|
|
|
CK_TILE_HOST void start(const hipStream_t& s)
|
|
{
|
|
HIP_CHECK_ERROR(hipStreamSynchronize(s));
|
|
HIP_CHECK_ERROR(hipEventRecord(start_evt, s));
|
|
}
|
|
|
|
CK_TILE_HOST void stop(const hipStream_t& s)
|
|
{
|
|
HIP_CHECK_ERROR(hipEventRecord(stop_evt, s));
|
|
HIP_CHECK_ERROR(hipEventSynchronize(stop_evt));
|
|
}
|
|
// return in ms
|
|
CK_TILE_HOST float duration() const
|
|
{
|
|
float ms = 0;
|
|
HIP_CHECK_ERROR(hipEventElapsedTime(&ms, start_evt, stop_evt));
|
|
return ms;
|
|
}
|
|
|
|
private:
|
|
hipEvent_t start_evt, stop_evt;
|
|
};
|
|
|
|
struct cpu_timer
|
|
{
|
|
// torch.utils.benchmark.Timer(), there is a sync inside each timer callback
|
|
CK_TILE_HOST void start(const hipStream_t& s)
|
|
{
|
|
HIP_CHECK_ERROR(hipStreamSynchronize(s));
|
|
start_tick = high_res_now();
|
|
}
|
|
// torch.utils.benchmark.Timer(), there is a sync inside each timer callback
|
|
CK_TILE_HOST void stop(const hipStream_t& s)
|
|
{
|
|
HIP_CHECK_ERROR(hipStreamSynchronize(s));
|
|
stop_tick = high_res_now();
|
|
}
|
|
// return in ms
|
|
CK_TILE_HOST float duration() const
|
|
{
|
|
auto us = duration_us(start_tick, stop_tick);
|
|
return static_cast<float>(us) / 1e3;
|
|
}
|
|
|
|
private:
|
|
timepoint_t start_tick;
|
|
timepoint_t stop_tick;
|
|
};
|
|
|
|
} // namespace ck_tile
|